@@ -22,7 +22,7 @@ setClass("List",
 
 setGeneric("elementType", function(x, ...) standardGeneric("elementType"))
 setMethod("elementType", "List", function(x) x@elementType)
-setMethod("elementType", "vector", function(x) mode(x))
+setMethod("elementType", "vector", function(x) storage.mode(x))
 
 setGeneric("elementLengths", function(x) standardGeneric("elementLengths"))
 
@@ -86,7 +86,7 @@ setMethod("show", "List",
               cat(classNameForDisplay(object), " of length ", lo,
                   "\n", sep = "")
               if (!is.null(names(object)))
-                cat(BiocGenerics:::labeledLine("names", names(object)))
+                cat(labeledLine("names", names(object)))
           })
 
 
@@ -482,7 +482,9 @@ phead <- function(x, n=6L)
     n <- .normarg_n(n, x_eltlens)
     unlisted_i <- IRanges(start=rep.int(1L, length(n)), width=n)
     i <- relist(unlisted_i, PartitioningByEnd(seq_along(x)))
-    x[i]
+    ans <- x[i]
+    mcols(ans) <- mcols(x)
+    ans
 }
 
 ptail <- function(x, n=6L)
@@ -491,7 +493,9 @@ ptail <- function(x, n=6L)
     n <- .normarg_n(n, x_eltlens)
     unlisted_i <- IRanges(end=x_eltlens, width=n)
     i <- relist(unlisted_i, PartitioningByEnd(seq_along(x)))
-    x[i]
+    ans <- x[i]
+    mcols(ans) <- mcols(x)
+    ans
 }
 
 
