@@ -196,18 +196,26 @@ setMethod("which.max", "Rle",
           })
 
 ## base::ifelse works fine for S4 'test', but not for S4 yes/no
+.ifelse_generic_deprecation_msg <- c(
+    "  The \"ifelse\" methods for Rle objects are deprecated. Please use",
+    "\n\n      as(ifelse(test, as.vector(yes), as.vector(no)), \"Rle\")",
+    "\n\n  instead."
+)
 setMethod("ifelse", c(yes = "Rle"), function(test, yes, no) 
           {
+            .Deprecated(msg=.ifelse_generic_deprecation_msg)
             yes <- as.vector(yes)
             as(callGeneric(), "Rle")
           })
 setMethod("ifelse", c(no = "Rle"), function(test, yes, no) 
           {
+            .Deprecated(msg=.ifelse_generic_deprecation_msg)
             no <- as.vector(no)
             as(callGeneric(), "Rle")
           })
 setMethod("ifelse", c(yes = "Rle", no = "Rle"), function(test, yes, no) 
           {
+            .Deprecated(msg=.ifelse_generic_deprecation_msg)
             yes <- as.vector(yes)
             no <- as.vector(no)
             as(callGeneric(), "Rle")
@@ -530,9 +538,10 @@ setMethod("runq", "Rle",
 ### Other character data methods
 ###
 
-.nchar_Rle <- function(x, type = "chars", allowNA = FALSE)
-    Rle(values = nchar(runValue(x), type = type, allowNA = allowNA),
-        lengths = runLength(x), check = FALSE)
+setMethod("nchar", "Rle",
+          function(x, type = "chars", allowNA = FALSE)
+              Rle(values = nchar(runValue(x), type = type, allowNA = allowNA),
+                  lengths = runLength(x), check = FALSE))
 
 setMethod("substr", "Rle",
           function(x, start, stop)
@@ -678,6 +687,26 @@ setMethod("paste", "Rle",
               ans
           })
 
+setMethod("grepl", c("ANY", "Rle"),
+          function(pattern, x, ignore.case = FALSE, perl = FALSE,
+                   fixed = FALSE, useBytes = FALSE) {
+              v <- grepl(pattern, runValue(x), ignore.case, perl, fixed,
+                         useBytes)
+              Rle(v, runLength(x))
+          })
+
+setMethod("grep", c("ANY", "Rle"),
+          function(pattern, x, ignore.case = FALSE, perl = FALSE, value = FALSE,
+                   fixed = FALSE, useBytes = FALSE, invert = FALSE) {
+              if (isTRUE(value)) {
+                  v <- grep(pattern, x, ignore.case, perl, value=TRUE, fixed,
+                            useBytes, invert)
+                  Rle(v, runLength(x))
+              } else { # obviously inefficient
+                  Rle(callNextMethod())
+              }
+          })
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Other factor data methods
 ###
