@@ -10,14 +10,16 @@ setClassUnion("characterORNULL", c("character", "NULL"))
 ### is( ,"list") makes no sense:
 ###   1. is.vector(matrix()) is FALSE but is(matrix(), "vector") is TRUE.
 ###   2. is.list(data.frame()) is TRUE but is(data.frame(), "list") is FALSE.
-###   3. is.vector(data.frame()) is FALSE but is.list(data.frame()) and
+###   3. is(data.frame(), "list") is FALSE but extends("data.frame", "list")
+###      is TRUE.
+###   4. is.vector(data.frame()) is FALSE but is.list(data.frame()) and
 ###      is.vector(list()) are both TRUE. In other words: a data frame is a
 ###      list and a list is a vector but a data frame is not a vector.
-###   4. I'm sure there is more but you get it!
+###   5. I'm sure there is more but you get it!
 ### Building our software on top of such a mess won't give us anything good.
 ### For example, it's not too surprising that the union class we define below
 ### is broken:
-###   5. is(data.frame(), "vectorORfactor") is TRUE even though
+###   6. is(data.frame(), "vectorORfactor") is TRUE even though
 ###      is(data.frame(), "vector") and is(data.frame(), "factor") are both
 ###      FALSE.
 ### Results above obtained with R-3.1.2 and R-3.2.0.
@@ -151,6 +153,82 @@ setMethods <- function(f, signatures=list(), definition,
 }
 
 
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### setReplaceAs()
+###
+### Supplying a "coerce<-" method to the 'replace' argument of setAs() is
+### optional but not supplying a "coerce" method (thru the 'def' argument).
+### However there are legitimate situations where we want to define a
+### "coerce<-" method only. setReplaceAs() can be used for that.
+###
+
+### Same interface as setAs() (but no 'replace' argument).
+setReplaceAs <- function(from, to, def, where=topenv(parent.frame()))
+{
+    ## Code below taken from setAs() and slightly adapted.
+
+    args <- formalArgs(def)
+    if (identical(args, c("from", "to", "value"))) {
+        method <- def
+    } else {
+        if (length(args) != 2L) 
+            stop(gettextf("the method definition must be a function of 2 ",
+                          "arguments, got %d", length(args)), domain=NA)
+        def <- body(def)
+        if (!identical(args, c("from", "value"))) {
+            ll <- list(quote(from), quote(value))
+            names(ll) <- args
+            def <- substituteDirect(def, ll)
+            warning(gettextf("argument names in method definition changed ",
+                             "to agree with 'coerce<-' generic:\n%s",
+                             paste(deparse(def), sep="\n    ")), domain=NA)
+        }
+        method <- eval(function(from, to, value) NULL)
+        functionBody(method, envir=.GlobalEnv) <- def
+    }
+    setMethod("coerce<-", c(from, to), method, where=where)
+}
+
+### We also provide 2 canonical "coerce<-" methods that can be used when the
+### "from class" is a subclass of the "to class". They do what the methods
+### automatically generated by the methods package are expected to do except
+### that the latter are broken. See
+###     https://bugs.r-project.org/bugzilla/show_bug.cgi?id=16421
+### for the bug report.
+
+### Naive/straight-forward implementation (easy to understand so it explains
+### the semantic of canonical "coerce<-").
+canonical_replace_as <- function(from, to, value)
+{
+    for (what in slotNames(to))
+        slot(from, what) <- slot(value, what)
+    from
+}
+
+### Does the same as canonical_replace_as() but tries to generate only one
+### copy of 'from' instead of one copy each time one of its slots is modified.
+canonical_replace_as_2 <- function(from, to, value)
+{
+    firstTime <- TRUE
+    for (what in slotNames(to)) {
+        v <- slot(value, what)
+        if (firstTime) {
+            slot(from, what, FALSE) <- v
+            firstTime <- FALSE
+        } else {
+            `slot<-`(from, what, FALSE, v)
+        }
+    }
+    from
+}
+
+### Usage (assuming B is a subclass of A):
+###
+###   setReplaceAs("B", "A", canonical_replace_as_2)
+###
+### Note that this is used in the VariantAnnotation package.
+
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Manipulating the prototype of an S4 class.
 ###
