@@ -45,10 +45,10 @@ setMethod("parallelSlotNames", "Vector", function(x) "elementMetadata")
 ### Methods for Vector subclasses only need to specify the parallel slots they
 ### add to their parent class. See Hits-class.R file for an example.
 
-### fixedColumnNames() is for internal use only.
-### TODO: Deprecate fixedColumnNames(). Use parallelSlotNames() instead.
-setGeneric("fixedColumnNames", function(x) standardGeneric("fixedColumnNames"))
-setMethod("fixedColumnNames", "ANY", function(x) character())
+### parallelVectorNames() is for internal use only.
+setGeneric("parallelVectorNames",
+           function(x) standardGeneric("parallelVectorNames"))
+setMethod("parallelVectorNames", "ANY", function(x) character())
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -59,6 +59,18 @@ setMethod("length", "Vector",
     function(x) NROW(slot(x, parallelSlotNames(x)[[1L]]))
 )
 
+setMethod("lengths", "Vector",
+     function(x, use.names=TRUE)
+     {
+         if (!isTRUEorFALSE(use.names))
+             stop("'use.names' must be TRUE or FALSE")
+         ans <- elementLengths(x)
+         if (!use.names)
+             names(ans) <- NULL
+         ans
+     }
+)
+
 setMethod("NROW", "Vector", function(x) length(x))
 setMethod("ROWNAMES", "Vector", function(x) names(x))
 
@@ -221,6 +233,8 @@ setAs("Vector", "complex", function(from) as.complex(from))
 setAs("Vector", "character", function(from) as.character(from))
 setAs("Vector", "raw", function(from) as.raw(from))
 
+setAs("Vector", "factor", function(from) as.factor(from))
+
 setAs("Vector", "data.frame", function(from) as.data.frame(from))
 
 ### S3/S4 combo for as.data.frame.Vector
@@ -233,8 +247,9 @@ setMethod("as.data.frame", "Vector", as.data.frame.Vector)
 
 makeFixedColumnEnv <- function(x, parent, tform = identity) {
   env <- new.env(parent=parent)
-  lapply(fixedColumnNames(x), function(nm) {
-    accessor <- get(nm, parent, mode="function")
+  pvnEnv <- environment(selectMethod("parallelVectorNames", class(x)))
+  lapply(parallelVectorNames(x), function(nm) {
+    accessor <- get(nm, pvnEnv, mode="function")
     makeActiveBinding(nm, function() {
       val <- tform(accessor(x))
       rm(list=nm, envir=env)
@@ -288,12 +303,13 @@ setReplaceMethod("values", "Vector",
                      x
                  })
 
-setGeneric("rename", function(x, value, ...) standardGeneric("rename"))
+setGeneric("rename", function(x, ...) standardGeneric("rename"))
 
-.renameVector <- function(x, value, ...) {
-  if (missing(value))
-    newNames <- c(...)
-  else newNames <- c(value, ...)
+.renameVector <- function(x, ...) {
+  newNames <- c(...)
+  if (!is.character(newNames) || any(is.na(newNames))) {
+      stop("arguments in '...' must be character and not NA")
+  }
   badOldNames <- setdiff(names(newNames), names(x))
   if (length(badOldNames))
     stop("Some 'from' names in value not found on 'x': ",
@@ -340,9 +356,8 @@ setMethod("extractROWS", "Vector",
         ## Does NOT validate the object before returning it, because, most of
         ## the times, this is not needed. There are exceptions though. See
         ## for example the "extractROWS" method for Hits objects.
-        do.call(BiocGenerics:::updateS4, c(list(x),
-                                           ans_pslots,
-                                           list(check=FALSE)))
+        do.call(BiocGenerics:::replaceSlots,
+                c(list(x), ans_pslots, list(check=FALSE)))
     }
 )
 
