@@ -118,8 +118,8 @@ void R_init_S4Vectors(DllInfo *info)
 	REGISTER_CCALLABLE(_IntAE_get_nelt);
 	REGISTER_CCALLABLE(_IntAE_set_nelt);
 	REGISTER_CCALLABLE(_IntAE_set_val);
-	REGISTER_CCALLABLE(_new_IntAE);
 	REGISTER_CCALLABLE(_IntAE_insert_at);
+	REGISTER_CCALLABLE(_new_IntAE);
 	REGISTER_CCALLABLE(_IntAE_append);
 	REGISTER_CCALLABLE(_IntAE_delete_at);
 	REGISTER_CCALLABLE(_IntAE_shift);
@@ -132,8 +132,8 @@ void R_init_S4Vectors(DllInfo *info)
 	REGISTER_CCALLABLE(_new_IntAE_from_CHARACTER);
 	REGISTER_CCALLABLE(_IntAEAE_get_nelt);
 	REGISTER_CCALLABLE(_IntAEAE_set_nelt);
-	REGISTER_CCALLABLE(_new_IntAEAE);
 	REGISTER_CCALLABLE(_IntAEAE_insert_at);
+	REGISTER_CCALLABLE(_new_IntAEAE);
 	REGISTER_CCALLABLE(_IntAEAE_eltwise_append);
 	REGISTER_CCALLABLE(_IntAEAE_shift);
 	REGISTER_CCALLABLE(_IntAEAE_sum_and_shift);
@@ -142,30 +142,30 @@ void R_init_S4Vectors(DllInfo *info)
 	REGISTER_CCALLABLE(_IntAEAE_toEnvir);
 	REGISTER_CCALLABLE(_IntPairAE_get_nelt);
 	REGISTER_CCALLABLE(_IntPairAE_set_nelt);
-	REGISTER_CCALLABLE(_new_IntPairAE);
 	REGISTER_CCALLABLE(_IntPairAE_insert_at);
+	REGISTER_CCALLABLE(_new_IntPairAE);
 	REGISTER_CCALLABLE(_IntPairAEAE_get_nelt);
 	REGISTER_CCALLABLE(_IntPairAEAE_set_nelt);
-	REGISTER_CCALLABLE(_new_IntPairAEAE);
 	REGISTER_CCALLABLE(_IntPairAEAE_insert_at);
-	REGISTER_CCALLABLE(_LongLongIntAE_get_nelt);
-	REGISTER_CCALLABLE(_LongLongIntAE_set_nelt);
-	REGISTER_CCALLABLE(_LongLongIntAE_set_val);
-	REGISTER_CCALLABLE(_new_LongLongIntAE);
-	REGISTER_CCALLABLE(_LongLongIntAE_insert_at);
+	REGISTER_CCALLABLE(_new_IntPairAEAE);
+	REGISTER_CCALLABLE(_LLongAE_get_nelt);
+	REGISTER_CCALLABLE(_LLongAE_set_nelt);
+	REGISTER_CCALLABLE(_LLongAE_set_val);
+	REGISTER_CCALLABLE(_LLongAE_insert_at);
+	REGISTER_CCALLABLE(_new_LLongAE);
 	REGISTER_CCALLABLE(_CharAE_get_nelt);
 	REGISTER_CCALLABLE(_CharAE_set_nelt);
+	REGISTER_CCALLABLE(_CharAE_insert_at);
 	REGISTER_CCALLABLE(_new_CharAE);
 	REGISTER_CCALLABLE(_new_CharAE_from_string);
-	REGISTER_CCALLABLE(_CharAE_insert_at);
 	REGISTER_CCALLABLE(_append_string_to_CharAE);
 	REGISTER_CCALLABLE(_CharAE_delete_at);
 	REGISTER_CCALLABLE(_new_RAW_from_CharAE);
 	REGISTER_CCALLABLE(_new_LOGICAL_from_CharAE);
 	REGISTER_CCALLABLE(_CharAEAE_get_nelt);
 	REGISTER_CCALLABLE(_CharAEAE_set_nelt);
-	REGISTER_CCALLABLE(_new_CharAEAE);
 	REGISTER_CCALLABLE(_CharAEAE_insert_at);
+	REGISTER_CCALLABLE(_new_CharAEAE);
 	REGISTER_CCALLABLE(_append_string_to_CharAEAE);
 	REGISTER_CCALLABLE(_new_CHARACTER_from_CharAEAE);
 
